@@ -103,6 +103,10 @@ class BaseHandler(RequestHandler):
         self.write(key+u'(' + s + u')')
 
 class StaticFileHandler(_StaticFileHandler):
+    def initialize(self, path, default_filename=None, debug=False, **kwargs):
+        super(StaticFileHandler, self).initialize(path, default_filename)
+        self.debug = debug
+        self.kwargs = kwargs
     static_handler = True
 
 class ErrorHandler(_ErrorHandler): 
